@@ -77,7 +77,7 @@ void Window:: CreateButtons()
 	QPushButton *exit = new QPushButton(this);
 	QPushButton *help = new QPushButton(this);
 
-	help->setGeometry(700,150, 45,45);
+	help->setGeometry(700,130, 45,45);
 	help->setIconSize(QSize(45,45));
 	help->setIcon(QPixmap(":/images/help3.png"));
 	help->setFlat(true);
@@ -85,8 +85,8 @@ void Window:: CreateButtons()
 	newgame->setIconSize(QSize(45,45));
 	newgame->setIcon(QPixmap(":/images/new3.png"));
 	newgame->setFlat(true);
-	exit->setGeometry(700,250, 45,45);
-	exit->setIconSize(QSize(45,45));
+	exit->setGeometry(700,270, 45,45);
+	exit->setIconSize(QSize(60,60));
 	exit->setIcon(QPixmap(":/images/quit.png"));
 	exit->setFlat(true);
 
@@ -145,7 +145,7 @@ QAbstractButton *Window :: setIcon(int id)
 		if(won){
                         disconnect(bgroup, SIGNAL(buttonClicked(int)), this, SLOT(setIcon(int)));
 			int res = QMessageBox::warning(this, tr("CONGRATULATIONS!"),
-                   		  tr("U Won................\n"
+                   		  tr("You Won................\n"
                       		  "Do you want to Play a new game?"),
                    		  QMessageBox::Yes | QMessageBox::No,
                    		  QMessageBox::Yes);
@@ -213,8 +213,11 @@ void Window :: exitfun()
 
 void Window :: helpfun()
 {
-	QMessageBox::information(this,"Help!", "Block the cat by Clicking the blocks\n"
-						"In Such a way cat that it gets captured");
+	QMessageBox::information(this,"Help!", "Block the cat by clicking the blocks\n"
+	"in such a way that it gets captured\n"
+	"NOTE: Use 'Ctrl + Backspace'  to switch between applications");
+	
+		
 	
 }
 
